Welcome to conn2svg's documentation!
====================================

.. include:: ../README.rst
   :start-after: start-intro
   :end-before: end-intro

Repository
==========

Code is maintained on GitHub: `github.com/partmanager/conn2svg <https://github.com/partmanager/conn2svg>`_.
